==> eiffelstudio-18.01.10.1424.tar: F_code/C2/kl55.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl55.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F76_862 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F76_863 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F76_864 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F76_865 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F76_866 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F76_867 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F76_868 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F76_869 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F76_870 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_79(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F11_82(RTCW(loc1));
	}
	ti4_1 = F11_83(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_84(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_85(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_86(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_87(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_88(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_89(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F76_871 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_80(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F11_82(RTCW(loc1));
	}
	ti4_1 = F11_83(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_84(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_85(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_86(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_87(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_88(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_89(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.utc_clock */
EIF_REFERENCE F76_872 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {KL_SYSTEM_CLOCK}.local_clock */
EIF_REFERENCE F76_873 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit55 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/kl55.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl55.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F76_897 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F76_898 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F76_899 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F76_900 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F76_901 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F76_902 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F76_903 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F76_904 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F76_905 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(5, 0x01).id, 5, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F6_56(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F6_59(RTCW(loc1));
	}
	ti4_1 = F6_60(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_61(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_62(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_63(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_64(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_65(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_66(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F76_906 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(5, 0x01).id, 5, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F6_57(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F6_59(RTCW(loc1));
	}
	ti4_1 = F6_60(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_61(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_62(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_63(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_64(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_65(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F6_66(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

void EIF_Minit55 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
